from twisted.internet.task import react

import treq


async def basic_get(reactor):
    resp = await treq.get("https://httpbin.org/get")
    print(resp.code, resp.phrase)
    print(resp.headers)
    print(await resp.text())


react(basic_get)



from _utils import print_response
from twisted.internet.task import react
from twisted.web.client import Agent

from treq.client import HTTPClient


async def custom_agent(reactor):
    my_agent = Agent(reactor, connectTimeout=42)
    http_client = HTTPClient(my_agent)
    resp = await http_client.get(
        "https://secure.example.net/area51",
        auth=("admin", "you'll never guess!"),
    )
    await print_response(resp)


react(custom_agent)



from _utils import print_response
from twisted.internet.task import react

import treq


def basic_post(reactor):
    resp = await treq.post(
        "https://httpbin.org/post",
        data={"form": "data"},
    )
    await print_response(resp)


react(basic_post)



from twisted.internet.task import react

import treq


async def download_file(reactor, url, destination_filename):
    with open(destination_filename, "wb") as destination:
        response = await treq.get(url, unbuffered=True)
        await treq.collect(response, destination.write)


react(download_file, ["https://httpbin.org/get", "download.txt"])



from _utils import print_response
from hyperlink import DecodedURL
from twisted.internet.task import react

import treq


async def basic_url(reactor):
    url = (
        DecodedURL.from_text("https://httpbin.org")
        .child("get")  # add path /get
        .add("foo", "&")  # add query ?foo=%26
    )
    print(url.to_text())
    await print_response(await treq.get(url))


react(basic_url)



from _utils import print_response
from twisted.internet.task import react

import treq


async def basic_auth(reactor):
    resp = await treq.get(
        "https://httpbin.org/basic-auth/treq/treq",
        auth=("treq", "treq"),
    )
    await print_response(resp)


react(basic_auth)



from _utils import print_response
from twisted.internet.task import react

import treq


async def redirects(reactor):
    resp = await treq.get("https://httpbin.org/redirect/1")
    await print_response(resp)


react(redirects)



from twisted.internet.task import react

import treq


async def query_params(reactor):
    print("List of tuples")
    resp = await treq.get(
        "https://httpbin.org/get", params=[("foo", "bar"), ("baz", "bax")]
    )
    print(await resp.text())

    print("Single value dictionary")
    resp = await treq.get(
        "https://httpbin.org/get", params={"foo": "bar", "baz": "bax"}
    )
    print(await resp.text())

    print("Multi value dictionary")
    resp = await treq.get(
        "https://httpbin.org/get", params={b"foo": [b"bar", b"baz", b"bax"]}
    )
    print(await resp.text())

    print("Mixed value dictionary")
    resp = await treq.get(
        "https://httpbin.org/get",
        params={"foo": [1, 2, 3], "bax": b"quux", b"bar": "foo"},
    )
    print(await resp.text())

    print("Preserved query parameters")
    resp = await treq.get("https://httpbin.org/get?foo=bar", params={"baz": "bax"})
    print(await resp.text())


react(query_params)



from _utils import print_response
from twisted.internet.task import react

import treq


async def disable_redirects(reactor):
    resp = await treq.get(
        "https://httpbin.org/redirect/1",
        allow_redirects=False,
    )
    await print_response(resp)


react(disable_redirects)



from pprint import pprint

from twisted.internet.task import react

import treq


async def json_post(reactor):
    response = await treq.post(
        "https://httpbin.org/post",
        json={"msg": "Hello!"},
    )
    data = await response.json()
    pprint(data)


react(json_post)
